%define _distrib_milestone %(echo %_distrib_codename | cut -d- -f1)
%define majver %(echo %version | cut -d. -f1-3)
Name:          alsa-utils
Version:       1.2.13
Release:       2mamba
Summary:       Utilities for the Advanced Linux Sound Architecture (ALSA)
Group:         System/Kernel and Hardware
Vendor:        openmamba
Distribution:  openmamba
Packager:      Silvan Calarco <silvan.calarco@mambasoft.it>
URL:           https://www.alsa-project.org/wiki/Main_Page
Source:        https://github.com/alsa-project/alsa-utils.git/v%{version}/alsa-utils-%{version}%{?spl}.tar.bz2
Source1:       alsa-initscript
Source2:       alsa-asound.conf
Source3:       alsa-asound.conf-usb
Source4:       alsa-udev-asound.conf.rules
Patch0:        alsa-utils-1.0.19-alsaconf.patch
Patch1:        alsa-utils-1.2.13-upstream-fix_alsa_restore_rule.patch
License:       GPL
## AUTOBUILDREQ-BEGIN
BuildRequires: glibc-devel
BuildRequires: libalsa-devel
BuildRequires: libffado-devel
BuildRequires: libfftw-devel
BuildRequires: libncurses-devel
BuildRequires: libsamplerate-devel
## AUTOBUILDREQ-END
BuildRequires: libalsa-devel >= %{majver}
BuildRequires: xmlto
BuildRequires: docbook-utils
BuildRequires: /usr/bin/xsltproc
%systemd_requires

%description
The Advanced Linux Sound Architecture (ALSA) provides audio and MIDI functionality to the Linux operating system.

ALSA has the following significant features:
- efficient support for all types of audio interfaces, from consumer soundcards to professional multichannel audio interfaces
- fully modularized sound drivers
- SMP and thread-safe design
- user space library (alsa-lib) to simplify application programming and provide higher level functionality
- support for the older OSS API, providing binary compatibility for most OSS programs

%package midi
Summary:       Utilities for the Advanced Linux Sound Architecture (ALSA) MIDI Sequencer
Group:         System/Kernel and Hardware
Requires:      %{name} = %{version}-%{release}

%description midi
The Advanced Linux Sound Architecture (ALSA) provides audio and MIDI functionality to the Linux operating system.

ALSA has the following significant features:
- efficient support for all types of audio interfaces, from consumer soundcards to professional multichannel audio interfaces
- fully modularized sound drivers
- SMP and thread-safe design
- user space library (alsa-lib) to simplify application programming and provide higher level functionality
- support for the older OSS API, providing binary compatibility for most OSS programs

This package contains the utilities for the Advanced Linux Sound Architecture (ALSA) MIDI Sequencer.

%debug_package

%prep
%setup -q
%patch 0 -p1
%patch 1 -p1 -b .upstream-fix_alsa_restore_rule

autoreconf -f -i

%build
%configure
%make

%install
[ "%{buildroot}" != / ] && rm -rf %{buildroot}
%makeinstall

install -D -m0644 %{SOURCE2} %{buildroot}%{_sysconfdir}/asound.conf.alsa
install -D -m0644 %{SOURCE3} %{buildroot}%{_sysconfdir}/asound.conf.alsa-usb
#install -D -m644 %{SOURCE4} %{buildroot}/lib/udev/rules.d/59-alsa-usb-asoundconf.rules

cat > %{buildroot}%{_sysconfdir}/asound.conf.dummy << _EOF
# Dummy empty asound.conf
_EOF

# postplug one-shot update script for new gain controls
install -d %{buildroot}%{_sysconfdir}/postplug/updates.d
cat > %{buildroot}%{_sysconfdir}/postplug/updates.d/alsa-utils-set-gain-001.upd << _EOF
%{_sbindir}/alsactl restore
%{_bindir}/amixer sset 'Output Gain' 70%
%{_bindir}/amixer sset 'Capture Gain' 50%
%{_sbindir}/alsactl store
_EOF

install -d %{buildroot}%{_modulesloaddir}
cat >> %{buildroot}%{_modulesloaddir}/alsa-seq-midi.conf << _EOF
snd-seq-midi
_EOF

%find_lang %{name} --with-man --all-name

%clean
[ "%{buildroot}" != / ] && rm -rf %{buildroot}

%post
/usr/sbin/alternatives --install \
   %{_sysconfdir}/asound.conf asound.conf %{_sysconfdir}/asound.conf.alsa 20
/usr/sbin/alternatives --install \
   %{_sysconfdir}/asound.conf asound.conf %{_sysconfdir}/asound.conf.alsa-usb 10
/usr/sbin/alternatives --install \
   %{_sysconfdir}/asound.conf asound.conf %{_sysconfdir}/asound.conf.dummy 5
exit 0

%preun
# erase
if [ $1 -eq 0 ]; then
   /usr/sbin/update-alternatives --remove asound.conf %{_sysconfdir}/asound.conf.alsa
   /usr/sbin/update-alternatives --remove asound.conf %{_sysconfdir}/asound.conf.alsa-usb
   /usr/sbin/update-alternatives --remove asound.conf %{_sysconfdir}/asound.conf.dummy
fi
exit 0

%posttrans
/usr/sbin/alternatives --install \
   %{_sysconfdir}/asound.conf asound.conf %{_sysconfdir}/asound.conf.alsa 20
/usr/sbin/alternatives --install \
   %{_sysconfdir}/asound.conf asound.conf %{_sysconfdir}/asound.conf.alsa-usb 10
/usr/sbin/alternatives --install \
   %{_sysconfdir}/asound.conf asound.conf %{_sysconfdir}/asound.conf.dummy 5
exit 0

%post midi
# new install
if [ $1 -eq 1 ]; then
   modprobe snd-seq-midi || true
fi
exit 0


%files -f %{name}.lang
%defattr(-,root,root)
%config %{_sysconfdir}/asound.conf.alsa
%config %{_sysconfdir}/asound.conf.alsa-usb
%config %{_sysconfdir}/asound.conf.dummy
%{_sysconfdir}/postplug/updates.d/alsa-utils-set-gain-001.upd
%{_bindir}/aconnect
%{_bindir}/alsamixer
%{_bindir}/alsabat
%{_bindir}/alsaloop
%{_bindir}/alsaucm
%{_bindir}/alsatplg
%{_bindir}/amixer
%{_bindir}/aplay
%{_bindir}/arecord
%{_bindir}/aseqsend
%{_bindir}/axfer
%{_bindir}/iecset
%{_bindir}/nhlt-dmic-info
%{_bindir}/speaker-test
%{_sbindir}/alsaconf
%{_sbindir}/alsactl
%{_sbindir}/alsa-info.sh
%{_sbindir}/alsabat-test.sh
%{_udevrulesdir}/90-alsa-restore.rules
%{_unitdir}/alsa-restore.service
%{_unitdir}/alsa-state.service
%{_unitdir}/sound.target.wants/alsa-restore.service
%{_unitdir}/sound.target.wants/alsa-state.service
%{_libdir}/alsa-topology/libalsatplg_module_nhlt.so
%{_datadir}/alsa/init/*
%{_datadir}/sounds/alsa/*.wav
%dir /var/lib/alsa
%{_mandir}/man1/aconnect.1*
%{_mandir}/man1/alsa*.1*
%{_mandir}/man1/amixer.1*
%{_mandir}/man1/aplay.1*
%{_mandir}/man1/arecord.1*
%{_mandir}/man1/alsabat.1*
%{_mandir}/man1/axfer*.1*
%{_mandir}/man1/iecset.1*
%{_mandir}/man1/nhlt-dmic-info.1*
%{_mandir}/man1/speaker-test.1*
%{_mandir}/man7/alsactl_init.7*
%{_mandir}/man8/alsaconf.8*

%files midi
%defattr(-,root,root)
%{_modulesloaddir}/alsa-seq-midi.conf
%{_bindir}/amidi
%{_bindir}/aplaymidi
%{_bindir}/arecordmidi
%{_bindir}/aplaymidi2
%{_bindir}/arecordmidi2
%{_bindir}/aseqdump
%{_bindir}/aseqnet
%{_mandir}/man1/amidi.1*
%{_mandir}/man1/aplaymidi.1*
%{_mandir}/man1/aplaymidi2.1*
%{_mandir}/man1/arecordmidi.1*
%{_mandir}/man1/arecordmidi2.1*
%{_mandir}/man1/aseqdump.1*
%{_mandir}/man1/aseqnet.1*
%{_mandir}/man1/aseqsend.1*

%changelog
* Thu Nov 14 2024 Silvan Calarco <silvan.calarco@mambasoft.it> 1.2.13-2mamba
- appy upstream patch to fix udev restore rules file

* Thu Nov 14 2024 Automatic Build System <autodist@openmamba.org> 1.2.13-1mamba
- automatic version update by autodist

* Thu Jun 13 2024 Automatic Build System <autodist@openmamba.org> 1.2.12-1mamba
- automatic version update by autodist

* Wed Jan 31 2024 Automatic Build System <autodist@openmamba.org> 1.2.11-1mamba
- automatic version update by autodist

* Sun Sep 10 2023 Automatic Build System <autodist@mambasoft.it> 1.2.10-1mamba
- automatic version update by autodist

* Fri May 05 2023 Automatic Build System <autodist@mambasoft.it> 1.2.9-1mamba
- automatic version update by autodist

* Sat Oct 29 2022 Automatic Build System <autodist@mambasoft.it> 1.2.8-1mamba
- automatic version update by autodist

* Tue Jun 21 2022 Silvan Calarco <silvan.calarco@mambasoft.it> 1.2.7-2mamba
- fix permissions of /etc/asound.conf.alsa*

* Sat Jun 04 2022 Automatic Build System <autodist@mambasoft.it> 1.2.7-1mamba
- automatic version update by autodist

* Wed Dec 08 2021 Automatic Build System <autodist@mambasoft.it> 1.2.6-1mamba
- automatic version update by autodist

* Mon Jun 14 2021 Automatic Build System <autodist@mambasoft.it> 1.2.5.1-1mamba
- automatic version update by autodist

* Sat Jun 05 2021 Automatic Build System <autodist@mambasoft.it> 1.2.5-1mamba
- automatic version update by autodist

* Mon Oct 19 2020 Silvan Calarco <silvan.calarco@mambasoft.it> 1.2.4-1mamba
- update to 1.2.4

* Fri Jun 12 2020 Automatic Build System <autodist@mambasoft.it> 1.2.3-1mamba
- automatic version update by autodist

* Mon Feb 24 2020 Automatic Build System <autodist@mambasoft.it> 1.2.2-1mamba
- automatic version update by autodist

* Fri Nov 22 2019 Automatic Build System <autodist@mambasoft.it> 1.2.1-1mamba
- automatic version update by autodist

* Wed May 22 2019 Automatic Build System <autodist@mambasoft.it> 1.1.9-1mamba
- automatic version update by autodist

* Fri Mar 15 2019 Silvan Calarco <silvan.calarco@mambasoft.it> 1.1.8-2mamba
- move midi modules loading file to %_modulesloaddir

* Wed Jan 16 2019 Automatic Build System <autodist@mambasoft.it> 1.1.8-1mamba
- automatic version update by autodist

* Thu Oct 25 2018 Automatic Build System <autodist@mambasoft.it> 1.1.7-1mamba
- automatic version update by autodist

* Sun Apr 15 2018 Automatic Build System <autodist@mambasoft.it> 1.1.6-1mamba
- automatic version update by autodist

* Sun Dec 24 2017 Automatic Build System <autodist@mambasoft.it> 1.1.5-1mamba
- automatic version update by autodist

* Mon Jun 19 2017 Automatic Build System <autodist@mambasoft.it> 1.1.4-1mamba
- automatic version update by autodist

* Mon Aug 08 2016 Automatic Build System <autodist@mambasoft.it> 1.1.2-1mamba
- automatic version update by autodist

* Tue Apr 19 2016 Automatic Build System <autodist@mambasoft.it> 1.1.1-1mamba
- automatic version update by autodist

* Wed Nov 18 2015 Automatic Build System <autodist@mambasoft.it> 1.1.0-1mamba
- automatic version update by autodist

* Thu Mar 12 2015 Automatic Build System <autodist@mambasoft.it> 1.0.29-1mamba
- automatic version update by autodist

* Sun Sep 28 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0.28-2mamba
- remove alsa usb soundcard conf switch conflicting (and managed) now with pulseaudio

* Wed Jun 18 2014 Automatic Build System <autodist@mambasoft.it> 1.0.28-1mamba
- automatic version update by autodist

* Sat Dec 07 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0.27.2-2mamba
- add hotplug support for external usb device by using udev to switch to use external device as default

* Tue Jul 30 2013 Automatic Build System <autodist@mambasoft.it> 1.0.27.2-1mamba
- automatic version update by autodist

* Sat Jul 13 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0.27.1-4mamba
- asound.conf.alsa: integrate jack-alsa bridge kit (http://www.penguinproducer.com/Blog/2011/11/jack-alsa-bridge-kit/)

* Mon Jul 01 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0.27.1-3mamba
- remove code referring to obsolete initscript in %post script

* Wed Jun 26 2013 Automatic Build System <autodist@mambasoft.it> 1.0.27.1-2mamba
- arm: rebuild to fix alsamixer: undefined symbol: __aeabi_uidiv after ncurses update

* Thu May 23 2013 Automatic Build System <autodist@mambasoft.it> 1.0.27.1-1mamba
- automatic version update by autodist

* Sat Apr 20 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0.27-2mamba
- patch: fix a typo in systemd service file

* Mon Apr 15 2013 Automatic Build System <autodist@mambasoft.it> 1.0.27-1mamba
- automatic version update by autodist

* Sun Sep 23 2012 Automatic Build System <autodist@mambasoft.it> 1.0.26-1mamba
- automatic version update by autodist

* Sun Sep 02 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0.25-2mamba
- add an alternative for a dummy (empty) asound.conf (Raspberry PI)

* Wed Jun 06 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0.25-1mamba
- update to 1.0.25

* Sat Jun 02 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0.24.2-6mamba
- initscript: run alsactl init if alsactl restore fails to prevent a kmix crash on first boot

* Sat Mar 17 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0.24.2-5mamba
- initscript: again restore volumes on startup to fix an unexplained crash in kmix at first login (https://bugs.kde.org/show_bug.cgi?id=209975)

* Sat Nov 12 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0.24.2-4mamba
- initscript: don't unload modules on shutdown

* Sun Nov 06 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0.24.2-3mamba
- provide directory /var/lib/alsa which now contains ile asound.state

* Wed Mar 23 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0.24.2-2mamba
- set asound.conf as an alternative

* Sat Mar 19 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0.24.2-1mamba
- update to 1.0.24.2

* Thu Feb 17 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0.23-6mamba
- added .conf extension to /etc/modules.d/ file
- added subpackage alsa-utils-midi

* Mon Jan 31 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0.23-5mamba
- initscript: move to /etc/modules.d snd-seq-midi loading and load snd-seq-oss only if ENABLE_LEGACY_OSS is set

* Sun Jan 09 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0.23-4mamba
- don't own /usr/share/alsa

* Sat Nov 06 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0.23-3mamba
- added postplug one-shot update script for new gain controls

* Wed Sep 22 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0.23-2mamba
- asound.conf: added softvol controls for controlling Capture (+50dB) and Output (+20dB) gain

* Sat Apr 17 2010 Automatic Build System <autodist@mambasoft.it> 1.0.23-1mamba
- automatic update to 1.0.23 by autodist

* Mon Apr 12 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0.22-1mamba
- update to 1.0.22

* Thu Oct 22 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0.21-3mamba
- asound.conf: added skype capture device with swapped mic channels (http://wiki.debian.org/DebianEeePC/HowTo/Sound)

* Thu Oct 15 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0.21-2mamba
- asound.conf: use the asymed plug mixing both output and capture; add description for use with Phonon/KDE4

* Fri Oct 02 2009 Automatic Build System <autodist@mambasoft.it> 1.0.21-1mamba
- update to 1.0.21

* Thu May 07 2009 Automatic Build System <autodist@mambasoft.it> 1.0.20-1mamba
- automatic update to 1.0.20 by autodist

* Fri Jan 23 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0.19-1mamba
- automatic update by autodist

* Fri Jan 02 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0.18rc3-1mamba
- automatic update by autodist

* Mon Dec 22 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0.18-2mamba
- initscript: don't load OSS legacy modules if jack/oss2jack are disabled
- asound.conf: added file with dmix configuration as default and oss plug for aoss
- added build requirement for xmlto

* Mon Nov 17 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0.18-1mamba
- automatic update to 1.0.18 by autodist

* Thu Aug 21 2008 gil <puntogil@libero.it> 1.0.17-1mamba
- update to 1.0.17

* Sun Feb 17 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0.16-1mamba
- update to 1.0.16

* Sat Aug 11 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0.14-2mamba
- initscript moved here from libalsa

* Mon Jun 04 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0.14-1mamba
- update to 1.0.14

* Sun Oct 01 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0.13-1qilnx
- update to version 1.0.13 by autospec

* Wed Sep 27 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0.12-1qilnx
- update to version 1.0.12 by autospec

* Wed Apr 26 2006 Davide Madrisan <davide.madrisan@qilinux.it> 1.0.11-1qilnx
- update to version 1.0.11 by autospec

* Mon Nov 21 2005 Davide Madrisan <davide.madrisan@qilinux.it> 1.0.10-1qilnx
- update to version 1.0.10 by autospec
- updated patch
- fixed package group

* Wed Oct 26 2005 Davide Madrisan <davide.madrisan@qilinux.it> 1.0.9a-1qilnx
- update to version 1.0.9a by autospec

* Mon Feb 14 2005 Davide Madrisan <davide.madrisan@qilinux.it> 1.0.8-3qilnx
- new patch for alsaconf

* Fri Feb 11 2005 Davide Madrisan <davide.madrisan@qilinux.it> 1.0.8-2qilnx
- modified the `alsaconf' script for the QiLinux distro

* Tue Feb 01 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0.8-1qilnx
- update to version 1.0.8 by autospec

* Fri Nov 26 2004 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0.7-1qilnx
- update to version 1.0.7 by autospec

* Mon May 31 2004 Davide Madrisan <davide.madrisan@qilinux.it> 1.0.5-1qilnx
- rebuilt with alsa-utils-1.0.5

* Mon Apr 05 2004 Davide Madrisan <davide.madrisan@qilinux.it> 1.0.4-1qilnx
- rebuilt with alsa-utils-1.0.4

* Tue Mar 02 2004 Davide Madrisan <davide.madrisan@qilinux.it> 1.0.3-1qilnx
- rebuilt with alsa-utils-1.0.3

* Tue Jan 27 2004 Davide Madrisan <davide.madrisan@qilinux.it> 1.0.2-1qilnx
- rebuilt with version 1.0.2

* Fri Jan 09 2004 Davide Madrisan <davide.madrisan@qilinux.it> 1.0.1-1qilnx
- rebuilt with version 1.0.1

* Wed Dec 10 2003 Davide Madrisan <davide.madrisan@qilinux.it> 1.0.0rc2-1qilnx
- rebuilt with version 1.0.0rc2

* Wed Oct 22 2003 Davide Madrisan <davide.madrisan@qilinux.it> 0.9.8-1qilnx
- rebuilt with version 0.9.8

* Fri Sep 26 2003 Davide Madrisan <davide.madrisan@qilinux.it> 0.9.7-1qlnx
- rebuilt with version 0.9.7

* Tue Sep 02 2003 Davide Madrisan <davide.madrisan@qilinux.it> 0.9.6-1qlnx
- rebuilt with version 0.9.6

* Fri Jul 04 2003 Silvan Calarco <silvan.calarco@qinet.it> 0.9.4-1qilnx
- first build for alsa-utils
